@@ -29,6 +29,8 @@ enum generic
     Generic_Format_Commercial_IfAny,
     Generic_Format_Version,
     Generic_Format_Profile,
+    Generic_Format_Level,
+    Generic_Format_Tier,
     Generic_Format_Compression,
     Generic_Format_Settings,
     Generic_InternetMediaType,
@@ -163,6 +165,8 @@ enum general
     General_Inform,
     General_ID,
     General_ID_String,
+    General_OriginalSourceMedium_ID,
+    General_OriginalSourceMedium_ID_String,
     General_UniqueID,
     General_UniqueID_String,
     General_MenuID,
@@ -200,10 +204,12 @@ enum general
     General_Menu_Language_List,
     General_CompleteName,
     General_FolderName,
+    General_FileNameExtension,
     General_FileName,
     General_FileExtension,
     General_CompleteName_Last,
     General_FolderName_Last,
+    General_FileNameExtension_Last,
     General_FileName_Last,
     General_FileExtension_Last,
     General_Format,
@@ -215,6 +221,7 @@ enum general
     General_Format_Commercial_IfAny,
     General_Format_Version,
     General_Format_Profile,
+    General_Format_Level,
     General_Format_Compression,
     General_Format_Settings,
     General_InternetMediaType,
@@ -283,6 +290,13 @@ enum general
     General_StreamSize_String4,
     General_StreamSize_String5,
     General_StreamSize_Proportion,
+    General_StreamSize_Demuxed,
+    General_StreamSize_Demuxed_String,
+    General_StreamSize_Demuxed_String1,
+    General_StreamSize_Demuxed_String2,
+    General_StreamSize_Demuxed_String3,
+    General_StreamSize_Demuxed_String4,
+    General_StreamSize_Demuxed_String5,
     General_HeaderSize,
     General_DataSize,
     General_FooterSize,
@@ -297,6 +311,9 @@ enum general
     General_Encryption_Mode,
     General_Encryption_Padding,
     General_Encryption_InitializationVector,
+    General_UniversalAdID_String,
+    General_UniversalAdID_Registry,
+    General_UniversalAdID_Value,
     General_Title,
     General_Title_More,
     General_Title_Url,
@@ -344,6 +361,7 @@ enum general
     General_Accompaniment,
     General_Composer,
     General_Composer_Nationality,
+    General_Composer_Sort,
     General_Arranger,
     General_Lyricist,
     General_Original_Lyricist,
@@ -378,6 +396,7 @@ enum general
     General_Publisher_URL,
     General_Label,
     General_Genre,
+    General_PodcastCategory,
     General_Mood,
     General_ContentType,
     General_Subject,
@@ -444,7 +463,7 @@ enum general
     General_ServiceChannel,
     General_Service_Url,
     General_ServiceProvider,
-    General_ServiceProviderr_Url,
+    General_ServiceProvider_Url,
     General_ServiceType,
     General_NetworkName,
     General_OriginalNetworkName,
@@ -481,6 +500,8 @@ enum video
     Video_Inform,
     Video_ID,
     Video_ID_String,
+    Video_OriginalSourceMedium_ID,
+    Video_OriginalSourceMedium_ID_String,
     Video_UniqueID,
     Video_UniqueID_String,
     Video_MenuID,
@@ -492,10 +513,16 @@ enum video
     Video_Format_Commercial_IfAny,
     Video_Format_Version,
     Video_Format_Profile,
+    Video_Format_Level,
+    Video_Format_Tier,
     Video_Format_Compression,
     Video_MultiView_BaseProfile,
     Video_MultiView_Count,
     Video_MultiView_Layout,
+    Video_DolbyVision_String,
+    Video_DolbyVision_Version,
+    Video_DolbyVision_Profile,
+    Video_DolbyVision_Layers,
     Video_Format_Settings,
     Video_Format_Settings_BVOP,
     Video_Format_Settings_BVOP_String,
@@ -511,6 +538,8 @@ enum video
     Video_Format_Settings_RefFrames,
     Video_Format_Settings_RefFrames_String,
     Video_Format_Settings_Pulldown,
+    Video_Format_Settings_Endianness,
+    Video_Format_Settings_Packing,
     Video_Format_Settings_FrameMode,
     Video_Format_Settings_GOP,
     Video_Format_Settings_PictureStructure,
@@ -658,6 +687,8 @@ enum video
     Video_Colorimetry,
     Video_ColorSpace,
     Video_ChromaSubsampling,
+    Video_ChromaSubsampling_String,
+    Video_ChromaSubsampling_Position,
     Video_BitDepth,
     Video_BitDepth_String,
     Video_ScanType,
@@ -723,6 +754,13 @@ enum video
     Video_StreamSize_String4,
     Video_StreamSize_String5,
     Video_StreamSize_Proportion,
+    Video_StreamSize_Demuxed,
+    Video_StreamSize_Demuxed_String,
+    Video_StreamSize_Demuxed_String1,
+    Video_StreamSize_Demuxed_String2,
+    Video_StreamSize_Demuxed_String3,
+    Video_StreamSize_Demuxed_String4,
+    Video_StreamSize_Demuxed_String5,
     Video_Source_StreamSize,
     Video_Source_StreamSize_String,
     Video_Source_StreamSize_String1,
@@ -771,6 +809,8 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_ServiceKind,
+    Video_ServiceKind_String,
     Video_Disabled,
     Video_Disabled_String,
     Video_Default,
@@ -809,6 +849,8 @@ enum audio
     Audio_Inform,
     Audio_ID,
     Audio_ID_String,
+    Audio_OriginalSourceMedium_ID,
+    Audio_OriginalSourceMedium_ID_String,
     Audio_UniqueID,
     Audio_UniqueID_String,
     Audio_MenuID,
@@ -820,6 +862,7 @@ enum audio
     Audio_Format_Commercial_IfAny,
     Audio_Format_Version,
     Audio_Format_Profile,
+    Audio_Format_Level,
     Audio_Format_Compression,
     Audio_Format_Settings,
     Audio_Format_Settings_SBR,
@@ -996,6 +1039,13 @@ enum audio
     Audio_StreamSize_String4,
     Audio_StreamSize_String5,
     Audio_StreamSize_Proportion,
+    Audio_StreamSize_Demuxed,
+    Audio_StreamSize_Demuxed_String,
+    Audio_StreamSize_Demuxed_String1,
+    Audio_StreamSize_Demuxed_String2,
+    Audio_StreamSize_Demuxed_String3,
+    Audio_StreamSize_Demuxed_String4,
+    Audio_StreamSize_Demuxed_String5,
     Audio_Source_StreamSize,
     Audio_Source_StreamSize_String,
     Audio_Source_StreamSize_String1,
@@ -1049,6 +1099,8 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_ServiceKind,
+    Audio_ServiceKind_String,
     Audio_Disabled,
     Audio_Disabled_String,
     Audio_Default,
@@ -1077,6 +1129,8 @@ enum text
     Text_Inform,
     Text_ID,
     Text_ID_String,
+    Text_OriginalSourceMedium_ID,
+    Text_OriginalSourceMedium_ID_String,
     Text_UniqueID,
     Text_UniqueID_String,
     Text_MenuID,
@@ -1232,6 +1286,13 @@ enum text
     Text_StreamSize_String4,
     Text_StreamSize_String5,
     Text_StreamSize_Proportion,
+    Text_StreamSize_Demuxed,
+    Text_StreamSize_Demuxed_String,
+    Text_StreamSize_Demuxed_String1,
+    Text_StreamSize_Demuxed_String2,
+    Text_StreamSize_Demuxed_String3,
+    Text_StreamSize_Demuxed_String4,
+    Text_StreamSize_Demuxed_String5,
     Text_Source_StreamSize,
     Text_Source_StreamSize_String,
     Text_Source_StreamSize_String1,
@@ -1278,6 +1339,8 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_ServiceKind,
+    Text_ServiceKind_String,
     Text_Disabled,
     Text_Disabled_String,
     Text_Default,
@@ -1307,6 +1370,8 @@ enum other
     Other_Inform,
     Other_ID,
     Other_ID_String,
+    Other_OriginalSourceMedium_ID,
+    Other_OriginalSourceMedium_ID_String,
     Other_UniqueID,
     Other_UniqueID_String,
     Other_MenuID,
@@ -1342,6 +1407,41 @@ enum other
     Other_FrameRate_Num,
     Other_FrameRate_Den,
     Other_FrameCount,
+    Other_Delay,
+    Other_Delay_String,
+    Other_Delay_String1,
+    Other_Delay_String2,
+    Other_Delay_String3,
+    Other_Delay_String4,
+    Other_Delay_String5,
+    Other_Delay_Settings,
+    Other_Delay_DropFrame,
+    Other_Delay_Source,
+    Other_Delay_Source_String,
+    Other_Delay_Original,
+    Other_Delay_Original_String,
+    Other_Delay_Original_String1,
+    Other_Delay_Original_String2,
+    Other_Delay_Original_String3,
+    Other_Delay_Original_String4,
+    Other_Delay_Original_String5,
+    Other_Delay_Original_Settings,
+    Other_Delay_Original_DropFrame,
+    Other_Delay_Original_Source,
+    Other_Video_Delay,
+    Other_Video_Delay_String,
+    Other_Video_Delay_String1,
+    Other_Video_Delay_String2,
+    Other_Video_Delay_String3,
+    Other_Video_Delay_String4,
+    Other_Video_Delay_String5,
+    Other_Video0_Delay,
+    Other_Video0_Delay_String,
+    Other_Video0_Delay_String1,
+    Other_Video0_Delay_String2,
+    Other_Video0_Delay_String3,
+    Other_Video0_Delay_String4,
+    Other_Video0_Delay_String5,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
     Other_TimeStamp_FirstFrame_String1,
@@ -1361,6 +1461,8 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_ServiceKind,
+    Other_ServiceKind_String,
     Other_Disabled,
     Other_Disabled_String,
     Other_Default,
@@ -1386,6 +1488,8 @@ enum image
     Image_Inform,
     Image_ID,
     Image_ID_String,
+    Image_OriginalSourceMedium_ID,
+    Image_OriginalSourceMedium_ID_String,
     Image_UniqueID,
     Image_UniqueID_String,
     Image_MenuID,
@@ -1398,6 +1502,8 @@ enum image
     Image_Format_Commercial_IfAny,
     Image_Format_Version,
     Image_Format_Profile,
+    Image_Format_Settings_Endianness,
+    Image_Format_Settings_Packing,
     Image_Format_Compression,
     Image_Format_Settings,
     Image_Format_Settings_Wrapping,
@@ -1450,6 +1556,13 @@ enum image
     Image_StreamSize_String4,
     Image_StreamSize_String5,
     Image_StreamSize_Proportion,
+    Image_StreamSize_Demuxed,
+    Image_StreamSize_Demuxed_String,
+    Image_StreamSize_Demuxed_String1,
+    Image_StreamSize_Demuxed_String2,
+    Image_StreamSize_Demuxed_String3,
+    Image_StreamSize_Demuxed_String4,
+    Image_StreamSize_Demuxed_String5,
     Image_Encoded_Library,
     Image_Encoded_Library_String,
     Image_Encoded_Library_Name,
@@ -1463,6 +1576,8 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_ServiceKind,
+    Image_ServiceKind_String,
     Image_Disabled,
     Image_Disabled_String,
     Image_Default,
@@ -1500,6 +1615,8 @@ enum menu
     Menu_Inform,
     Menu_ID,
     Menu_ID_String,
+    Menu_OriginalSourceMedium_ID,
+    Menu_OriginalSourceMedium_ID_String,
     Menu_UniqueID,
     Menu_UniqueID_String,
     Menu_MenuID,
@@ -1554,11 +1671,13 @@ enum menu
     Menu_Language_String3,
     Menu_Language_String4,
     Menu_Language_More,
+    Menu_ServiceKind,
+    Menu_ServiceKind_String,
     Menu_ServiceName,
     Menu_ServiceChannel,
     Menu_Service_Url,
     Menu_ServiceProvider,
-    Menu_ServiceProviderr_Url,
+    Menu_ServiceProvider_Url,
     Menu_ServiceType,
     Menu_NetworkName,
     Menu_Original_NetworkName,
